@@ -172,6 +172,23 @@ predictionFunction <- function(method, modelFit, newdata, preProc = NULL, param
                              
                            },
                            
+                           lda2 = 
+                           {
+                             library(MASS)
+                             out <- as.character(predict(modelFit, newdata, dimen = modelFit$tuneValue$.dimen)$class)
+                             if(!is.null(param))
+                               {
+                                 tmp <- vector(mode = "list", length = nrow(param) + 1)
+                                 tmp[[1]] <- out
+                                 for(j in seq(along = param$.dimen))
+                                   {
+                                     tmp[[j+1]] <- as.character(predict(modelFit, newdata, dimen = param$.dimen[j])$class)
+                                   }
+                                 out <- tmp
+                               }                        
+                             out
+                           },
+                           
                            lvq =
                            {
                              library(class)
@@ -215,6 +232,7 @@ predictionFunction <- function(method, modelFit, newdata, preProc = NULL, param
                                }
                              out
                            },
+                      
 
                            pam =
                            {
