@@ -32,7 +32,7 @@ byComplexity <- function(x, model)
            },            
            rFerns =, rf =, rfNWS =, rfLSF =, parRF =, gpls =, pcr =, pls =, simpls =, widekernelpls =, PLS =, pam =, cforest =,
            nb =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =,
-           lars =, lars2 =, Linda =, QdaCov =, icr =, qrf =,Boruta =, kernelpls = ,
+           lars =, lars2 =, Linda =, QdaCov =, icr =, qrf =,Boruta =, kernelpls = , lda2 =,
            leapForward=, leapBackward=, leapSeq =, rpart2 =, ORFridge =, ORFpls =, ORFsvm =, ORFlog =, evtree =  
            {
              x[order(x[,1]),]
